:orphan:

.. This directory contains scripts to use as tutorials to understand the package
   Use plot_*.py for script that intend to display some feature and will be
   rendered in the package gallery

Gallery
=======

Example plots of available features



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="plot extracted t_air to compare to article figure 4">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_plot_t_air_thumb.png
    :alt:

  :ref:`sphx_glr__gallery_plot_t_air.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Air temperature</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Plot t_air - t_leaf to compare with fig3">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_plot_diff_t_air_leaf_thumb.png
    :alt:

  :ref:`sphx_glr__gallery_plot_diff_t_air_leaf.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Debug leaf temperature</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="plot extracted t_leaf to compare to article figure 3 E and K">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_plot_t_leaf_thumb.png
    :alt:

  :ref:`sphx_glr__gallery_plot_t_leaf.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Leaf temperature</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="plot extracted wp_leaf to compare to article figure 5">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_plot_wp_leaf_thumb.png
    :alt:

  :ref:`sphx_glr__gallery_plot_wp_leaf.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Leaf water potential</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="plot extracted An to compare to article figure 3 B and H">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_plot_an_thumb.png
    :alt:

  :ref:`sphx_glr__gallery_plot_an.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Photosynthesis</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="plot extracted gs to compare to article figure 3 A and G (caution wrong units on the plot, chec...">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_plot_gs_thumb.png
    :alt:

  :ref:`sphx_glr__gallery_plot_gs.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Stomatal conductance</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="plot extracted Ec to compare to article figure 3 c and I">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_plot_ec_thumb.png
    :alt:

  :ref:`sphx_glr__gallery_plot_ec.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Transpiration</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="plot extracted vpd to compare to article figure 4">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_plot_vpd_thumb.png
    :alt:

  :ref:`sphx_glr__gallery_plot_vpd.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">VPD</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="plot extracted vpd_leaf to compare to article figure 3">

.. only:: html

  .. image:: /_gallery/images/thumb/sphx_glr_plot_vpd_leaf_thumb.png
    :alt:

  :ref:`sphx_glr__gallery_plot_vpd_leaf.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">VPD leaf</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /_gallery/plot_t_air
   /_gallery/plot_diff_t_air_leaf
   /_gallery/plot_t_leaf
   /_gallery/plot_wp_leaf
   /_gallery/plot_an
   /_gallery/plot_gs
   /_gallery/plot_ec
   /_gallery/plot_vpd
   /_gallery/plot_vpd_leaf


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
